diff --git a/config/config.sample.php b/config/config.sample.php
index bf26172c494e4ebf04c9bd75a2d856bf82915ac2..864247b3735313277df83e9d4cd22a9c35abaa84 100644
--- a/config/config.sample.php
+++ b/config/config.sample.php
@@ -77,7 +77,9 @@ $CONFIG = array(
 
 /**
  * Where user files are stored; this defaults to ``data/`` in the ownCloud
- * directory. The SQLite database is also stored here, when you use SQLite.
+ * directory. The SQLite database is also stored here, when you use SQLite. (SQLite is 
+available only in ownCloud Community Edition)
+
  */
 'datadirectory' => '/var/www/owncloud/data',
 
@@ -822,7 +824,8 @@ $CONFIG = array(
 ),
 
 /**
- * Database types that are supported for installation.
+ * Database types that are supported for installation. (SQLite is available only in 
+   ownCloud Community Edition)
  *
  * Available:
  * 	- sqlite (SQLite3)